@@ -18,24 +18,21 @@
     Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
  */
 
-#include "commandentry.h"
 #include "animationresultitem.h"
+#include "commandentry.h"
 #include "lib/result.h"
 #include "lib/animationresult.h"
 
-#include <QFileDialog>
 #include <QDebug>
+#include <QFileDialog>
+#include <QMovie>
+
 #include <KLocalizedString>
 
-AnimationResultItem::AnimationResultItem(QGraphicsObject* parent)
-    : WorksheetImageItem(parent), ResultItem(), m_height(0), m_movie(nullptr)
-{
-    connect(this, SIGNAL(removeResult()), parentEntry(),
-            SLOT(removeResult()));
-}
-
-AnimationResultItem::~AnimationResultItem()
+AnimationResultItem::AnimationResultItem(QGraphicsObject* parent, Cantor::Result* result)
+    : WorksheetImageItem(parent), ResultItem(result), m_height(0), m_movie(nullptr)
 {
+    update();
 }
 
 double AnimationResultItem::setGeometry(double x, double y, double w)
@@ -48,7 +45,7 @@ double AnimationResultItem::setGeometry(double x, double y, double w)
 
 void AnimationResultItem::populateMenu(QMenu* menu, QPointF pos)
 {
-    addCommonActions(this, menu);
+    ResultItem::addCommonActions(this, menu);
 
     menu->addSeparator();
     if (m_movie) {
@@ -67,17 +64,17 @@ void AnimationResultItem::populateMenu(QMenu* menu, QPointF pos)
     emit menuCreated(menu, mapToParent(pos));
 }
 
-ResultItem* AnimationResultItem::updateFromResult(Cantor::Result* result)
+void AnimationResultItem::update()
 {
+    Q_ASSERT(m_result->type() == Cantor::AnimationResult::Type);
     QMovie* mov;
-    switch(result->type()) {
+    switch(m_result->type()) {
     case Cantor::AnimationResult::Type:
-        mov = static_cast<QMovie*>(result->data().value<QObject*>());
+        mov = static_cast<QMovie*>(m_result->data().value<QObject*>());
         setMovie(mov);
-        return this;
+        break;
     default:
-        deleteLater();
-        return create(parentEntry(), result);
+        break;
     }
 }
 
@@ -153,15 +150,3 @@ void AnimationResultItem::deleteLater()
 {
     WorksheetImageItem::deleteLater();
 }
-
-CommandEntry* AnimationResultItem::parentEntry()
-{
-    return qobject_cast<CommandEntry*>(parentObject());
-}
-
-Cantor::Result* AnimationResultItem::result()
-{
-    return parentEntry()->expression()->result();
-}
-
-
