@@ -32,11 +32,11 @@ class AdvancedPlotAssistant : public Cantor::Assistant
   Q_OBJECT
   public:
     AdvancedPlotAssistant( QObject* parent, QList<QVariant> args );
-    ~AdvancedPlotAssistant() override;
+    ~AdvancedPlotAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
 
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
 
 };
 
