@@ -28,14 +28,10 @@
 
 #include <QProcess>
 
-LuaSession::LuaSession( Cantor::Backend* backend) :
-    Session(backend),
-    m_process(0),
-    m_currentExpression(0)
-{
-}
-
-LuaSession::~LuaSession()
+LuaSession::LuaSession( Cantor::Backend* backend) : Session(backend),
+    m_L(nullptr),
+    m_process(nullptr),
+    m_currentExpression(nullptr)
 {
 }
 
@@ -98,7 +94,9 @@ void LuaSession::readOutput()
     }
 
     //merge outputs until lua's promt "> " appears, take care of the comment characters "-->"
-    if(m_currentExpression && !m_output.isEmpty() && m_output.endsWith(QLatin1String("> ")) && !m_output.endsWith(QLatin1String("-> "))) {
+    if(m_currentExpression && !m_output.isEmpty() && m_output.endsWith(QLatin1String("> "))
+        && !m_output.endsWith(QLatin1String("-> ")))
+    {
         // we have our complete output
         // clean the output and parse it and clear m_output;
         m_currentExpression->parseOutput(m_output);
@@ -128,6 +126,8 @@ void LuaSession::logout()
 {
     if(m_process)
         m_process->kill();
+
+    changeStatus(Status::Disable);
 }
 
 void LuaSession::interrupt()
@@ -136,11 +136,11 @@ void LuaSession::interrupt()
     changeStatus(Cantor::Session::Done);
 }
 
-Cantor::Expression* LuaSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave)
+Cantor::Expression* LuaSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave, bool internal)
 {
     changeStatus(Cantor::Session::Running);
 
-    m_currentExpression = new LuaExpression(this);
+    m_currentExpression = new LuaExpression(this, internal);
     connect(m_currentExpression, SIGNAL(statusChanged(Cantor::Expression::Status)), this, SLOT(expressionFinished(Cantor::Expression::Status)));
     m_currentExpression->setFinishingBehavior(behave);
     m_currentExpression->setCommand(cmd);
