@@ -22,18 +22,19 @@
 #define _PYTHONBACKEND_H
 
 #include "backend.h"
+#include <cantor_pythonbackend_export.h>
 
-class CANTOR_EXPORT PythonBackend : public Cantor::Backend
+class CANTOR_PYTHONBACKEND_EXPORT PythonBackend : public Cantor::Backend
 {
   Q_OBJECT
   public:
     explicit PythonBackend(QObject* parent = nullptr, const QList<QVariant> args = QList<QVariant>());
     ~PythonBackend() override;
 
-    Cantor::Backend::Capabilities capabilities() const Q_DECL_OVERRIDE;
+    Cantor::Backend::Capabilities capabilities() const override;
 
-    QWidget* settingsWidget(QWidget* parent) const Q_DECL_OVERRIDE;
-    KConfigSkeleton* config() const Q_DECL_OVERRIDE = 0;
+    QWidget* settingsWidget(QWidget* parent) const override;
+    KConfigSkeleton* config() const override = 0;
 };
 
 
