@@ -28,12 +28,13 @@ class PythonHighlighter : public Cantor::DefaultHighlighter
     Q_OBJECT
 
   public:
-    explicit PythonHighlighter(QObject* parent);
+    explicit PythonHighlighter(QObject* parent, const int pythonVersion);
     ~PythonHighlighter() override = default;
 
   public Q_SLOTS:
     void updateHighlight();
     void addVariable(const QString variable);
+    void clearVariables();
 
   protected:
     void highlightBlock(const QString& text) override;
