@@ -24,8 +24,9 @@
 #include <QObject>
 #include <QDomElement>
 
-#include "cantor_export.h"
+#include <cantor_export.h>
 
+class QFileSystemWatcher;
 class KZip;
 
 /**
@@ -40,7 +41,7 @@ class ExpressionPrivate;
 
 /**
  * An Expression object is used, to store the information needed when running a command of a Session
- * Evaluation of Expression is an asynchroneous process in most cases, so most of the members
+ * Evaluation of Expression is an asynchronous process in most cases, so most of the members
  * of this class are not useful directly after its construction. Therefore there are signals
  * indicating, when the Expression goes through the different stages of the Running process.
  * An Expression is never constructed directly, but by using Session::evaluateExpression()
@@ -54,23 +55,25 @@ class CANTOR_EXPORT Expression : public QObject
     enum Status{ Computing,   ///< The Expression is still being computed
 		 Done,        ///< The Running of the Expression is finished successfully
 		 Error,       ///< An Error occurred when running the Expression
-		 Interrupted  ///< The Expression was interrupted by the user while running
+		 Interrupted,  ///< The Expression was interrupted by the user while running
+     Queued ///< The Expression is in expression queue, waited for Computing
     };
 
     /**
      * Enum indicating how this Expression behaves on finishing
      */
-    enum FinishingBehavior { 
-	DoNotDelete,     ///< This Expression will not be deleted. This is the normal behaviour
-	DeleteOnFinish   /** < The Object will delete itself when finished. This is used for fire-and-forget commands.
-			       All output/results will be dropped
-			 */
+    enum FinishingBehavior {
+	   DoNotDelete,     ///< This Expression will not be deleted. This is the normal behaviour
+	   DeleteOnFinish   /** < The Object will delete itself when finished. This is used for fire-and-forget commands.
+			                 * All output/results will be dropped
+			                 */
     };
     /**
-     * Expression constructor. Should only be called from Session::evaulateExpression
+     * Expression constructor. Should only be called from Session::evaluateExpression
      * @param session the session, this Expression belongs to
+     * @param internal \c true if this expression is internal expression
      */
-    Expression( Session* session );
+    explicit Expression( Session* session, bool internal = false);
     /**
      * destructor
      */
@@ -78,19 +81,20 @@ class CANTOR_EXPORT Expression : public QObject
 
     /**
      * Evaluate the Expression. before this is called, you should set the Command first
-     * This method can be implemented asynchroneous, thus the Evaluation doesn't need to happen in the method,
+     * This method can be implemented asynchronous, thus the Evaluation doesn't need to happen in the method,
      * It can also only be scheduled for evaluating.
      * @see setCommand()
      */
     virtual void evaluate() = 0;
     /**
-     * Interrupt the running of the Expression. 
+     * Interrupt the running of the Expression.
      * This should set the state to Interrupted.
      */
     virtual void interrupt() = 0;
-    
+
     /**
      * Returns the unique id of the Expression
+     * or -1 for internal expressions
      * @return the unique id of the Expression
      */
     int id();
@@ -159,48 +163,48 @@ class CANTOR_EXPORT Expression : public QObject
      */
     Result* result();
 
+    /*!
+     * in case the expression has multiple outputs/results, those can be obtained with this functions.
+     * Everything else said for \sa result() applies here too.
+     * @return the vector with results, or an empty vector if nor results are available yet.
+     */
+    const QVector<Result*>& results() const;
+
     /**
      * Deletes the result of this expression.
      *
      */
-    void clearResult();
-    
+    void removeResult(Result* result);
+
+    /**
+     * Deletes the all results of this expression.
+     *
+     */
+    void clearResults();
+
     /**
      * Returns the status of this Expression
      * @return the status of this Expression
      */
     Status status();
 
+    /**
+     * Set the status
+     * statusChanged will be emitted
+     * @param status the new status
+     */
+    void setStatus(Status status);
+
     /**
      * Returns the Session, this Expression belongs to
      */
     Session* session();
 
-    /**
-     * returns an xml representation of this expression
-     * used for saving the worksheet
-     * @param doc DomDocument used for storing the information
-     * @return QDomElemt containing the representation of this Expression
-     */
-    QDomElement toXml(QDomDocument& doc);
-    /**
-     * saves all the data, that can't be saved in xml 
-     * in an extra file in the archive. for Example 
-     * images of plots
-     * @param archive a Zip archive, the data should be stored in
-     */
-    void saveAdditionalData(KZip* archive);
-
     /**
      * returns whether or not this expression is internal, or
      * comes from the user
      */
     bool isInternal();
-    /**
-     * mark this expression as an internal expression,
-     * so for example latex will not be run on it
-     */
-    void setInternal(bool internal);
 
   Q_SIGNALS:
     /**
@@ -211,6 +215,20 @@ class CANTOR_EXPORT Expression : public QObject
      * A Result of the Expression has arrived
      */
     void gotResult();
+    /**
+     * emitted when the results of the expression were deleted.
+     * @see clearResults()
+     */
+    void resultsCleared();
+    /**
+     * emitted when the results of the expression were deleted.
+     * @see clearResult(Result* result)
+     */
+    void resultRemoved(int index);
+    /**
+     * emitted when the result at the position @c index was replaced by a new result.
+     */
+    void resultReplaced(int index);
     /**
      * the status of the Expression has changed.
      * @param status the new status
@@ -225,6 +243,9 @@ class CANTOR_EXPORT Expression : public QObject
 
   //These are protected, because only subclasses will handle results/status changes
   protected:
+    // Protected constructor, useful for derived classes with own id setting strategy
+    Expression(Session* session, bool internal, int id);
+
     /**
      * Set the result of the Expression.
      * this will cause gotResult() to be emitted
@@ -234,17 +255,17 @@ class CANTOR_EXPORT Expression : public QObject
      * @param result the new result
      */
     void setResult(Result* result);
-    /**
-     * Set the status
-     * statusChanged will be emitted
-     * @param status the new status
-     */
-    void setStatus(Status status);
 
-  protected:
-    //returns a string of latex commands, that is inserted into the header. 
+    void addResult(Result*);
+
+    void replaceResult(int index, Result* result);
+
+    //returns a string of latex commands, that is inserted into the header.
     //used for example if special packages are needed
     virtual QString additionalLatexHeaders();
+
+    QFileSystemWatcher* fileWatcher();
+
   private:
     void renderResultAsLatex(Result* result);
     void latexRendered(LatexRenderer* renderer, Result* result);
