@@ -26,7 +26,7 @@
 #include <QVector>
 #include <QDebug>
 #include <QWidget>
-#include "cantor_export.h"
+#include <cantor_export.h>
 
 namespace Cantor
 {
@@ -46,7 +46,7 @@ class CANTOR_EXPORT Extension : public QObject
   public:
     ///Default constructor
     Extension( const QString& name, QObject* parent );
-    ~Extension() override;
+    ~Extension() override = default;
 };
 
 
@@ -59,7 +59,7 @@ class CANTOR_EXPORT HistoryExtension : public Extension
 {
   Q_OBJECT
   public:
-    HistoryExtension(QObject* parent);
+    explicit HistoryExtension(QObject* parent);
     ~HistoryExtension() override;
   public Q_SLOTS:
     /**
@@ -77,7 +77,7 @@ class CANTOR_EXPORT ScriptExtension : public Extension
 {
   Q_OBJECT
   public:
-    ScriptExtension(QObject* parent);
+    explicit ScriptExtension(QObject* parent);
     ~ScriptExtension() override;
   public Q_SLOTS:
     /**
@@ -124,7 +124,7 @@ class CANTOR_EXPORT CASExtension : public Extension
 {
   Q_OBJECT
   public:
-    CASExtension(QObject* parent);
+    explicit CASExtension(QObject* parent);
     ~CASExtension() override;
 
   public Q_SLOTS:
@@ -151,13 +151,13 @@ class CANTOR_EXPORT CASExtension : public Extension
 
 /**
  * An extension providing the basic calculus
- * stuff like limits, diffrentiate, integrate etc.
+ * stuff like limits, differentiate, integrate etc.
  */
 class CANTOR_EXPORT CalculusExtension : public Extension
 {
   Q_OBJECT
   public:
-    CalculusExtension(QObject* parent);
+    explicit CalculusExtension(QObject* parent);
     ~CalculusExtension() override;
 
   public Q_SLOTS:
@@ -172,7 +172,7 @@ class CANTOR_EXPORT CalculusExtension : public Extension
     /**
      * returns the command for calculating a differential
      * @param function the function
-     * @param variable the variable, after which shoudl be differentiated
+     * @param variable the variable, after which should be differentiated
      * @param times how often should be differentiated
      * @return the command to compute the differential
      */
@@ -180,14 +180,14 @@ class CANTOR_EXPORT CalculusExtension : public Extension
     /**
      * returns the command for calculating an integral
      * @param function the function
-     * @param variable the variable, after which shoudl be integrated
+     * @param variable the variable, after which should be integrated
      * @return the command to compute the integrate
      */
     virtual QString integrate(const QString& function, const QString& variable) = 0;
     /**
      * returns the command for calculating a definite integral
      * @param function the function
-     * @param variable the variable, after which shoudl be integrated
+     * @param variable the variable, after which should be integrated
      * @param left the left border of the integral
      * @param right the right border of the integral
      * @return the command to compute the integrate
@@ -205,7 +205,7 @@ class CANTOR_EXPORT PlotExtension : public Extension
     typedef QPair<QString,QString> Interval;
     typedef QPair<QString, Interval> VariableParameter;
 
-    PlotExtension(QObject* parent);
+    explicit PlotExtension(QObject* parent);
     ~PlotExtension() override;
 
   public Q_SLOTS:
@@ -225,7 +225,7 @@ class CANTOR_EXPORT PlotExtension : public Extension
      * @param var2 the parameters for Variable2 (name, interval)
      * @return the command for plotting
      */
-    virtual QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2) = 0;
+    virtual QString plotFunction3d(const QString& function, const VariableParameter& var1, const VariableParameter& var2) = 0;
 };
 
 #define PLOT_DIRECTIVE_DISPATCHING(x) QString dispatch(const Cantor::AdvancedPlotExtension::AcceptorBase& acc) const \
@@ -244,7 +244,7 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
 {
   Q_OBJECT
   public:
-    AdvancedPlotExtension(QObject* parent);
+    explicit AdvancedPlotExtension(QObject* parent);
     ~AdvancedPlotExtension() override;
 
     // TODO comment
@@ -255,7 +255,7 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
     class CANTOR_EXPORT DirectiveProducer : public QWidget
     {
         public:
-            DirectiveProducer(QWidget* parent);
+            explicit DirectiveProducer(QWidget* parent);
             virtual PlotDirective* produceDirective() const=0;
     };
 
@@ -264,16 +264,16 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
         public:
             DirectiveControl(QWidget* parent) : DirectiveProducer(parent) { UI::setupUi(this); }
         protected:
-            typedef DirectiveControl<UI> AbstractParent;
+            using AbstractParent = DirectiveControl<UI>;
     };
 
     class CANTOR_EXPORT AcceptorBase
     {
         public:
             /**
-             * utilitary typename for easying the code
+             * utilitary typename for easing the code
              */
-            typedef DirectiveProducer * (*widgetProc)(QWidget*);
+            using widgetProc = DirectiveProducer *(*)(QWidget *);
 
             /**
              * returns a constant reference to the list of widget generating procedures
@@ -287,7 +287,7 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
              * constructor only allowed for derived classes
              **/
             AcceptorBase();
-            virtual ~AcceptorBase();
+            virtual ~AcceptorBase() = default;
 
             QVector<widgetProc> m_widgets;
     };
@@ -313,7 +313,7 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
     class CANTOR_EXPORT PlotDirective
     {
         public:
-            virtual ~PlotDirective();
+            virtual ~PlotDirective() = default;
 
             /**
              * creates a new widget for editing the value and returns the pointer to it
@@ -333,7 +333,7 @@ class CANTOR_EXPORT AdvancedPlotExtension : public Extension
             /**
              * only derived classes may construct
              **/
-            PlotDirective();
+            PlotDirective() = default;
     };
 
   public Q_SLOTS:
@@ -378,9 +378,9 @@ class CANTOR_EXPORT LinearAlgebraExtension : public Extension
   Q_OBJECT
   public:
     enum VectorType { ColumnVector, RowVector };
-    typedef QList<QStringList> Matrix;
+    using Matrix = QList<QStringList>;
 
-    LinearAlgebraExtension(QObject* parent);
+    explicit LinearAlgebraExtension(QObject* parent);
     ~LinearAlgebraExtension() override;
 
   public Q_SLOTS:
@@ -400,7 +400,7 @@ class CANTOR_EXPORT LinearAlgebraExtension : public Extension
      **/
     virtual QString nullVector(int size, Cantor::LinearAlgebraExtension::VectorType type);
     /**
-     * creates a maxtrix with the given entries
+     * creates a matrix with the given entries
      * @param matrix the entries of the matrix
      * @return the command to create this matrix
      */
@@ -457,7 +457,7 @@ class CANTOR_EXPORT VariableManagementExtension : public Extension
 {
   Q_OBJECT
   public:
-    VariableManagementExtension( QObject* parent );
+    explicit VariableManagementExtension( QObject* parent );
     ~VariableManagementExtension() override;
 
   public Q_SLOTS:
@@ -477,7 +477,7 @@ class CANTOR_EXPORT PackagingExtension : public Extension
 {
   Q_OBJECT
   public:
-    PackagingExtension(QObject* parent);
+    explicit PackagingExtension(QObject* parent);
     ~PackagingExtension() override;
 
   public Q_SLOTS:
