@@ -23,7 +23,7 @@
 
 #include <QObject>
 
-#include "cantor_export.h"
+#include <cantor_export.h>
 
 #include "expression.h"
 
@@ -51,8 +51,10 @@ class CANTOR_EXPORT Session : public QObject
 {
   Q_OBJECT
   public:
-    enum Status { Running, ///< the session is busy, running some expression
-		  Done     ///< the session has done all the jobs, and is now waiting for more
+    enum Status {
+      Running, ///< the session is busy, running some expression
+		  Done,    ///< the session has done all the jobs, and is now waiting for more
+      Disable ///< the session don't login yet, or already logout
     };
 
     /**
@@ -60,7 +62,7 @@ class CANTOR_EXPORT Session : public QObject
      * thats job of the login() function
      * @see login()
      */
-    Session( Backend* backend);
+    explicit Session( Backend* backend);
     /**
      * Destructor
      */
@@ -70,32 +72,33 @@ class CANTOR_EXPORT Session : public QObject
      * Login to the Session. In this function you should do anything needed to set up
      * the session, and make it ready for usage. The method should be implemented non-blocking.
      * Emit loginStarted() prior to connection to the actual backend in order to notify cantor_part about it.
-     * If the loging in is completed, the loginDone() signal must be emitted
+     * If the logging in is completed, the loginDone() signal must be emitted
      */
     virtual void login() = 0;
     /**
      * Log out of the Session. Destroy everything specific to a single session, e.g.
-     * stop all the running processes etc.
-     * NOTE: restaring the session consists of first logout() and then login()
+     * stop all the running processes etc. Also logout session status must be Status::Disable
+     * NOTE: restarting the session consists of first logout() and then login()
      */
     virtual void logout() = 0;
 
     /**
      * Passes the given command to the backend and returns a Pointer
-     * to a new Expression object, which will emit the resultArrived()
+     * to a new Expression object, which will emit the gotResult()
      * signal as soon as the computation is done. The result will
-     * then be acessible by Expression::result()
+     * then be accessible by Expression::result()
      * @param command the command that should be run by the backend.
      * @param finishingBehavior the FinishingBehaviour that should be used for this command. @see Expression::FinishingBehaviour
+     * @param internal true, if it is an internal command @see Expression::Expression(Session*, bool)
      * @return an Expression object, representing this command
      */
-    virtual Expression* evaluateExpression(const QString& command, Expression::FinishingBehavior finishingBehavior) = 0;
+    virtual Expression* evaluateExpression(const QString& command, Expression::FinishingBehavior finishingBehavior = Expression::FinishingBehavior::DoNotDelete, bool internal = false) = 0;
 
     /**
-     * Reimplements evaluateExpression, setting the finishingBehaviour to DoNotDelete
-     * @see evaluateExpressionconst(QString& command, Expression::FinishingBehavior finishingBehavior)
+     * Append the expression to queue .
+     * @see expressionQueue() const
      */
-    Expression* evaluateExpression(const QString& command);
+    void enqueueExpression(Expression*);
 
     /**
      * Interrupts all the running calculations in this session
@@ -118,7 +121,7 @@ class CANTOR_EXPORT Session : public QObject
     /**
      * Returns Syntax help, for this command.
      * It returns a SyntaxHelpObject, that will fetch the
-     * needed information asynchroneousely. You need to listen
+     * needed information asynchronously. You need to listen
      * to the done() Signal of the Object
      * @param cmd the command, syntax help is requested for
      * @return SyntaxHelpObject, representing the help request
@@ -190,6 +193,21 @@ class CANTOR_EXPORT Session : public QObject
      */
     void changeStatus(Cantor::Session::Status newStatus);
 
+    /**
+     * Session can process one single expression at one time.
+     * Any other expressions submitted by the user are queued first until they get processed.
+     * The expression queue implements the FIFO mechanism.
+     * The queud expression have the status \c Expression::Queued.
+     */
+    QList<Expression*>& expressionQueue() const;
+
+    /**
+     * Execute first expression in expression queue.
+     * Also, this function changes the status from Queued to Computing.
+     * @see expressionQueue() const
+     */
+    virtual void runFirstExpression();
+
 Q_SIGNALS:
     void statusChanged(Cantor::Session::Status newStatus);
     void loginStarted();
